@@ -1,3 +1,7 @@
+USER_AGENT = (
+    "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36"
+)
+
 ZOOM_OUT = {
 	'40.7590615, -73.969231': 'Manhattan, NY',
 }
